Documentation
¶
Index ¶
- func LoggingPipe(src io.ReadWriteCloser, dst io.ReadWriteCloser) (int64, int64)
- func Pipe(src io.ReadWriteCloser, dst io.ReadWriteCloser) (int64, int64)
- func PipeWithTee(src io.ReadWriteCloser, dst io.ReadWriteCloser, srcToDstTap io.Writer, ...) (int64, int64)
- type Logger
- func (l *Logger) Debugf(f string, args ...interface{})
- func (l *Logger) Errorf(f string, args ...interface{}) error
- func (l *Logger) Fork(prefix string, args ...interface{}) *Logger
- func (l *Logger) Infof(f string, args ...interface{})
- func (l *Logger) IsDebug() bool
- func (l *Logger) IsInfo() bool
- func (l *Logger) Prefix() string
- type LoggingReadWriteCloser
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LoggingPipe ¶
func LoggingPipe(src io.ReadWriteCloser, dst io.ReadWriteCloser) (int64, int64)
func Pipe ¶
func Pipe(src io.ReadWriteCloser, dst io.ReadWriteCloser) (int64, int64)
func PipeWithTee ¶
func PipeWithTee(src io.ReadWriteCloser, dst io.ReadWriteCloser, srcToDstTap io.Writer, dstToSrcTap io.Writer) (int64, int64)
PipeWithTee copies bytes bidirectionally between src and dst like Pipe, but allows tapping into each direction by providing optional writers. srcToDstTap receives a copy of bytes flowing from src -> dst. dstToSrcTap receives a copy of bytes flowing from dst -> src. Taps are best-effort and should be non-blocking; if tap Write blocks or fails, the copy continues regardless.
Types ¶
type Logger ¶
type Logger struct {
Info, Debug bool
// contains filtered or unexported fields
}
Logger is pkg/log Logger with prefixing and 2 log levels
func NewLoggerFlag ¶
type LoggingReadWriteCloser ¶
type LoggingReadWriteCloser struct {
// contains filtered or unexported fields
}
func NewLoggingReadWriteCloser ¶
func NewLoggingReadWriteCloser(rw io.ReadWriteCloser, logger *Logger, prefix string) *LoggingReadWriteCloser
func (*LoggingReadWriteCloser) Close ¶
func (l *LoggingReadWriteCloser) Close() error
Click to show internal directories.
Click to hide internal directories.